%% BENJAMIN WONG
%  MONASH UNIVERSITY
%  October 2019
%  This file replicates
%  Kamber, Gunes and Benjamin Wong "Global Factors and Trend Inflation,"
%  Journal of International Economics, forthcoming
%
%%
addpath(genpath('_func'))
addpath('data')
addpath('Results')

clear all
clc
%% PROMPTS
disp('Baseline - Figures 2-8, Figure A1')
disp('Robustness - Figures 9')
disp('Prior Robustness - Figures B1 - B7')
disp('Common Trend - Figures B8 - B13')
disp('Other Robustness - Figure B14 - B20')
prompt = 'Which Specification?   ';
Specification = input(prompt,'s')

input_options

%%
options.max_factors = 10;   %set maximum number of factors
options.GCTest_LOS = 0.01;      % Level of significance for Granger Causality Test

%% MAIN ESTIMATION

tic
if strcmp(Specification,'Other Robustness') == 0
    Estimation
end

if strcmp(Specification,'Other Robustness') == 1
    Estimation
    save('Results\Baseline','Sample','Com_shocks_shares','FS_STNR','Foreign_shocks_shares','MVSTNR','other_foreign_shocks_shares','taupi')
    Estimate_other_specifications1
    save('Results\Relax_Block_Exogenous','Sample','Com_shocks_shares','FS_STNR','Foreign_shocks_shares','MVSTNR','other_foreign_shocks_shares','taupi')
    Estimate_other_specifications2
    save('Results\drop_stock_prices','Com_shocks_shares','FS_STNR','Foreign_shocks_shares','MVSTNR','other_foreign_shocks_shares','taupi')
    Estimate_other_specifications3
    save('Results\Orthogonalize_stock_prices','Com_shocks_shares','FS_STNR','Foreign_shocks_shares','MVSTNR','other_foreign_shocks_shares','taupi')
end


if strcmp(Specification,'Prior Robustness') == 1
    save('Results\lambda_point_five','Com_shocks_shares','FS_STNR','Foreign_shocks_shares','MVSTNR','other_foreign_shocks_shares','taupi')
    lambda = 0.2;
    Estimation
    save('Results\Baseline','Sample','Com_shocks_shares','FS_STNR','Foreign_shocks_shares','MVSTNR','other_foreign_shocks_shares','taupi')
    lambda = 0.1;
    Estimation
    save('Results\lambda_point_one','Com_shocks_shares','FS_STNR','Foreign_shocks_shares','MVSTNR','other_foreign_shocks_shares','taupi')
end

toc

%% PLOT STUFF

if strcmp(Specification,'Baseline') == 1
    Figures_2_to_8_and_A1
elseif strcmp(Specification,'Common Trend') == 1
    Figures_B8_to_B13
elseif strcmp(Specification,'Prior Robustness') == 1
    Figures_B1_to_B7
elseif strcmp(Specification,'Other Robustness') == 1
    Figures_B14_to_B20
elseif strcmp(Specification,'Robustness') == 1
    figure
    subplot(1,2,1);
    boxplot(FS_STNR,char(Sample))
    set(gca,'FontSize',14)
    title('\eta^* = \eta = 3')
    [h pvalue_t_test] = ttest2(FS_STNR(1:7),...
        FS_STNR(8:end),'Vartype','unequal','Tail','left');
    disp('One Sided Test for Equal \delta^F across both samples, \eta=\eta^*=3 (p value)')
    disp(pvalue_t_test)
    
    
    % Remove the BRIC countries then rerun the estimation
    country_code([8 10 15 24]) = [];
    FS_STNR = [];
    Sample = [];
    Sample = cell(1,1);
    Specification = 'Baseline';     %change to baseline so that the factors are chosen by GC test and cutting BRIC countries out
    Estimation
    subplot(1,2,2)
    boxplot(FS_STNR,char(Sample))
    set(gca,'FontSize',14)
    title('Omit BRIC')
    
    [h pvalue_t_test] = ttest2(FS_STNR(1:7),...
        FS_STNR(8:end),'Vartype','unequal','Tail','left');
    disp('One Sided Test for Equal \delta^F across both samples, BRIC-less Sample  (p value)')
    disp(pvalue_t_test)
end
