% Benjamin Wong
% RBNZ
% Nov 2014
% Updated Nov 2017 to reflect the backcasting of initial conditions
% and exogenous variables for GC testing

function p_value = granger_causality_exo(y,p,exo,test_eqn,excluded_var)
%Does Granger Causality Tests on a chisquare(n) distribution
%NO CONSTANT

%% INPUTS
%y              Data(TxN)
%p              lags
%exo            exogenous variables. reflects error correction terms
%               use [] if no exogenous variable
%test_eqn       index of equation to do test on
%excluded_var   index of excluded variables (put in a vector)

%% OUTPUT
%p_value        p_value of test

%% Estimate reduced form VAR
M = size(y,2);           % number of variables
y = [zeros(p,M);y];

[A,SIGMA,U,invXX] = olsvar_exo(y,p,exo,'No Constant');


%% Do Granger Causality Test

%M = size(y,2);           % number of variables
k = size(excluded_var,1); %number of excluded variables

%Single equation covariance matrix
covar = SIGMA(test_eqn,test_eqn)*invXX;

%Get index of coefficients to test restrictions on
index = [];

for i = 1:k
    index = [index excluded_var(i,1):M:M*p];
end

index = sort(index);

%covariance matrix to construct test statistic
test_covar = covar(index,index);
test_coeff = A(index,test_eqn);

test_stat = (test_coeff')*(test_covar\test_coeff);

p_value = 1-chi2cdf(test_stat,k*p);

end

